@@ -420,12 +420,16 @@ sub collapse_sibling_evals {
 }
 
 
-# should return the filename that the application used
-# when loading the file
+# Should return the filename that the application used when loading the file
+# For evals should remove the @INC portion from within the "(eval N)[$path]"
+# and similarly for Class::MOP #line evals "... defined at $path".
+# This is a bit of a fudge. Filename handling should be improved in the profiler.
 sub filename_without_inc {
     my $self = shift;
     my $f    = [$self->filename];
-    strip_prefix_from_paths([$self->profile->inc], $f);
+    strip_prefix_from_paths([$self->profile->inc], $f,
+        qr/(?: ^ | \[ | \sdefined\sat\s )/x
+    );
     return $f->[0];
 }
 
@@ -567,7 +571,7 @@ sub dump {
 
             for my $subname (sort keys %$subs_called) {
                 my @sc = @{$subs_called->{$subname}};
-                $sc[NYTP_SCi_CALLING_SUB] = join "|", keys %{ $sc[NYTP_SCi_CALLING_SUB] };
+                $sc[NYTP_SCi_CALLING_SUB] = join "|", sort keys %{ $sc[NYTP_SCi_CALLING_SUB] };
 
                 printf $fh "%s%s%s%s%s%s%s[ %s ]\n", 
                     $prefix, 'call', $separator,
